@@ -59,6 +59,7 @@
              (gnu system)
              (gnu system vm)
              (gnu system install)
+             (gnu tests)
              (srfi srfi-1)
              (srfi srfi-26)
              (ice-9 match))
@@ -71,19 +72,20 @@
 (define* (package->alist store package system
                          #:optional (package-derivation package-derivation))
   "Convert PACKAGE to an alist suitable for Hydra."
-  `((derivation . ,(derivation-file-name
-                    (package-derivation store package system
-                                        #:graft? #f)))
-    (description . ,(package-synopsis package))
-    (long-description . ,(package-description package))
-    (license . ,(package-license package))
-    (home-page . ,(package-home-page package))
-    (maintainers . ("bug-guix@gnu.org"))
-    (max-silent-time . ,(or (assoc-ref (package-properties package)
-                                       'max-silent-time)
-                            3600))                ; 1 hour by default
-    (timeout . ,(or (assoc-ref (package-properties package) 'timeout)
-                    72000)))) ; 20 hours by default
+  (parameterize ((%graft? #f))
+    `((derivation . ,(derivation-file-name
+                      (package-derivation store package system
+                                          #:graft? #f)))
+      (description . ,(package-synopsis package))
+      (long-description . ,(package-description package))
+      (license . ,(package-license package))
+      (home-page . ,(package-home-page package))
+      (maintainers . ("bug-guix@gnu.org"))
+      (max-silent-time . ,(or (assoc-ref (package-properties package)
+                                         'max-silent-time)
+                              3600))              ;1 hour by default
+      (timeout . ,(or (assoc-ref (package-properties package) 'timeout)
+                      72000)))))                  ;20 hours by default
 
 (define (package-job store job-name package system)
   "Return a job called JOB-NAME that builds PACKAGE on SYSTEM."
@@ -128,6 +130,9 @@ SYSTEM."
          (file (string-append dir "/demo-os.scm")))
     (read-operating-system file)))
 
+(define %guixsd-supported-systems
+  '("x86_64-linux" "i686-linux"))
+
 (define (qemu-jobs store system)
   "Return a list of jobs that build QEMU images for SYSTEM."
   (define (->alist drv)
@@ -142,12 +147,14 @@ system.")
   (define (->job name drv)
     (let ((name (symbol-append name (string->symbol ".")
                                (string->symbol system))))
-      `(,name . ,(cut ->alist drv))))
+      `(,name . ,(lambda ()
+                   (parameterize ((%graft? #f))
+                     (->alist drv))))))
 
   (define MiB
     (expt 2 20))
 
-  (if (member system '("x86_64-linux" "i686-linux"))
+  (if (member system %guixsd-supported-systems)
       (list (->job 'qemu-image
                    (run-with-store store
                      (mbegin %store-monad
@@ -164,6 +171,36 @@ system.")
                                           (* 1024 MiB))))))
       '()))
 
+(define (system-test-jobs store system)
+  "Return a list of jobs for the system tests."
+  (define (test->thunk test)
+    (lambda ()
+      (define drv
+        (run-with-store store
+          (mbegin %store-monad
+            (set-current-system system)
+            (set-grafting #f)
+            (set-guile-for-build (default-guile))
+            (system-test-value test))))
+
+      `((derivation . ,(derivation-file-name drv))
+        (description . ,(format #f "GuixSD '~a' system test"
+                                (system-test-name test)))
+        (long-description . ,(system-test-description test))
+        (license . ,gpl3+)
+        (home-page . ,%guix-home-page-url)
+        (maintainers . ("bug-guix@gnu.org")))))
+
+  (define (->job test)
+    (let ((name (string->symbol
+                 (string-append "test." (system-test-name test)
+                                "." system))))
+      (cons name (test->thunk test))))
+
+  (if (member system %guixsd-supported-systems)
+      (map ->job (all-system-tests))
+      '()))
+
 (define (tarball-jobs store system)
   "Return Hydra jobs to build the self-contained Guix binary tarball."
   (define (->alist drv)
@@ -178,7 +215,9 @@ all its dependencies, and ready to be installed on non-GuixSD distributions.")
   (define (->job name drv)
     (let ((name (symbol-append name (string->symbol ".")
                                (string->symbol system))))
-      `(,name . ,(cut ->alist drv))))
+      `(,name . ,(lambda ()
+                   (parameterize ((%graft? #f))
+                     (->alist drv))))))
 
   ;; XXX: Add a job for the stable Guix?
   (list (->job 'binary-tarball
@@ -269,6 +308,7 @@ valid."
                                                 system))))
                        (append (filter-map job all)
                                (qemu-jobs store system)
+                               (system-test-jobs store system)
                                (tarball-jobs store system)
                                (cross-jobs system))))
                     ((core)
