@@ -18,8 +18,9 @@
 
 (define-module (gnu packages fish)
   #:use-module (guix licenses)
-  #:use-module (gnu packages doxygen)
+  #:use-module (gnu packages documentation)
   #:use-module (gnu packages ncurses)
+  #:use-module (gnu packages python)
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix utils)
@@ -28,14 +29,14 @@
 (define-public fish
   (package
     (name "fish")
-    (version "2.1.2")
+    (version "2.3.1")
     (source (origin
               (method url-fetch)
-              (uri (string-append "http://fishshell.com/files/"
+              (uri (string-append "https://fishshell.com/files/"
                                   version "/fish-" version ".tar.gz"))
               (sha256
                (base32
-                "1pgnz5lapm4qk48a13k9698jaswybzlbz2nyc621d852ldf0vhn6"))
+                "0r46p64lg6da3v6chsa4gisvl04kd3rpy60yih8r870kbp9wm2ij"))
               (modules '((guix build utils)))
               ;; Don't try to install /etc/fish/config.fish.
               (snippet
@@ -45,7 +46,8 @@
     (native-inputs
      `(("doxygen" ,doxygen)))
     (inputs
-     `(("ncurses" ,ncurses)))
+     `(("ncurses" ,ncurses)
+       ("python" ,python-wrapper)))   ;for fish_config and manpage completions
     (arguments
      '(#:tests? #f ; no check target
        #:configure-flags '("--sysconfdir=/etc")))
@@ -59,5 +61,5 @@ has extensive and discoverable help.  A special help command gives access to
 all the fish documentation in your web browser.  Other features include smart
 terminal handling based on terminfo, an easy to search history, and syntax
 highlighting.")
-    (home-page "http://fishshell.com/")
+    (home-page "https://fishshell.com/")
     (license gpl2)))
