@@ -1,8 +1,10 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2015 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2015, 2016 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2015 Tomáš Čech <sleep_walker@gnu.org>
 ;;; Copyright © 2016 Leo Famulari <leo@famulari.name>
 ;;; Copyright © 2016 Ricardo Wurmus <rekado@elephly.net>
+;;; Copyright © 2016 Efraim Flashner <efraim@flashner.co.il>
+;;; Copyright © 2016 Andreas Enge <andreas@enge.fr>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -31,9 +33,13 @@
   #:use-module (gnu packages audio)
   #:use-module (gnu packages autotools)
   #:use-module (gnu packages bash)
+  #:use-module (gnu packages bison)
   #:use-module (gnu packages boost)
+  #:use-module (gnu packages documentation)
+  #:use-module (gnu packages haskell)
   #:use-module (gnu packages image)
   #:use-module (gnu packages python)
+  #:use-module (gnu packages flex)
   #:use-module (gnu packages fontutils)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages pulseaudio)  ;libsndfile, libsamplerate
@@ -41,13 +47,19 @@
   #:use-module (gnu packages multiprecision)
   #:use-module (gnu packages boost)
   #:use-module (gnu packages gl)
+  #:use-module (gnu packages glib)
+  #:use-module (gnu packages graphviz)
+  #:use-module (gnu packages gtk)
+  #:use-module (gnu packages gnome)
   #:use-module (gnu packages image)
   #:use-module (gnu packages jemalloc)
   #:use-module (gnu packages photo)
   #:use-module (gnu packages python)
   #:use-module (gnu packages qt)
+  #:use-module (gnu packages readline)
   #:use-module (gnu packages sdl)
   #:use-module (gnu packages video)
+  #:use-module (gnu packages xml)
   #:use-module (gnu packages xorg))
 
 (define-public blender
@@ -108,7 +120,7 @@
        ("libjpeg" ,libjpeg)
        ("libpng" ,libpng)
        ("libtiff" ,libtiff)
-       ("ffmpeg" ,ffmpeg)
+       ("ffmpeg-2.8" ,ffmpeg-2.8) ;<https://lists.gnu.org/archive/html/guix-devel/2016-04/msg01019.html>
        ("fftw" ,fftw)
        ("jack" ,jack-1)
        ("libsndfile" ,libsndfile)
@@ -129,15 +141,15 @@ application can be customized via its API for Python scripting.")
 (define-public cgal
   (package
     (name "cgal")
-    (version "4.6.3")
+    (version "4.8.1")
     (source (origin
               (method url-fetch)
               (uri (string-append
-                    "http://gforge.inria.fr/frs/download.php/file/"
-                    "35139/CGAL-4.6.3.tar.xz"))
+                    "https://github.com/CGAL/cgal/releases/download/releases/"
+                    "CGAL-" version "/CGAL-" version ".tar.xz"))
               (sha256
                (base32
-                "08gwjjh0qz3fakj1y2nsl2qvb0qv5lc7k1pxwjkagh37hxxh4f73"))))
+                "1c41yzl2jg3d6zx5k0iccwqwibp950q7dr7z7pp4xi9wlph3c87s"))))
     (build-system cmake-build-system)
     (arguments
      '(;; "RelWithDebInfo" is not supported.
@@ -176,7 +188,7 @@ many more.")
               (sha256
                (base32
                 "1izddjwbh1grs8080vmaix72z469qy29wrvkphgmqmcm0sv1by7c"))
-              (patches (map search-patch '("ilmbase-fix-tests.patch")))))
+              (patches (search-patches "ilmbase-fix-tests.patch"))))
     (build-system gnu-build-system)
     (home-page "http://www.openexr.com/")
     (synopsis "Utility C++ libraries for threads, maths, and exceptions")
@@ -201,10 +213,18 @@ exception-handling library.")
                 "0ca2j526n4wlamrxb85y2jrgcv0gf21b3a19rr0gh4rjqkv1581n"))
               (modules '((guix build utils)))
               (snippet
-               '(substitute* (find-files "." "tmpDir\\.h")
-                  (("\"/var/tmp/\"")
-                   "\"/tmp/\"")))
-              (patches (list (search-patch "openexr-missing-samples.patch")))))
+               '(begin
+                  (substitute* (find-files "." "tmpDir\\.h")
+                    (("\"/var/tmp/\"")
+                     "\"/tmp/\""))
+
+                  ;; Install 'ImfStdIO.h'.  Reported at
+                  ;; <https://lists.nongnu.org/archive/html/openexr-devel/2016-06/msg00001.html>
+                  ;; and <https://github.com/openexr/openexr/pull/184>.
+                  (substitute* "IlmImf/Makefile.in"
+                    (("ImfIO\\.h")
+                     "ImfIO.h ImfStdIO.h"))))
+              (patches (search-patches "openexr-missing-samples.patch"))))
     (build-system gnu-build-system)
     (arguments
      '(#:phases
@@ -236,7 +256,7 @@ storage of the \"EXR\" file format for storing 16-bit floating-point images.")
 (define-public openimageio
   (package
     (name "openimageio")
-    (version "1.5.18")
+    (version "1.6.15")
     (source (origin
               (method url-fetch)
               (uri (string-append "https://github.com/OpenImageIO/oiio/"
@@ -244,8 +264,7 @@ storage of the \"EXR\" file format for storing 16-bit floating-point images.")
               (file-name (string-append name "-" version ".tar.gz"))
               (sha256
                (base32
-                "0mn7cz19mn8dcrhkq15h25gl20ammr1wz0j2j3c2vxs6ph7zn8jy"))
-              (patches (list (search-patch "openimageio-boost-1.60.patch")))))
+                "144crq0205d0w5aq4iglh2rhzf54a8rv3pksy6d533b75w5d7rq7"))))
     (build-system cmake-build-system)
     ;; FIXME: To run all tests successfully, test image sets from multiple
     ;; third party sources have to be present.  For details see
@@ -272,6 +291,77 @@ visual effects work for film.")
     (home-page "http://www.openimageio.org")
     (license license:bsd-3)))
 
+(define-public rapicorn
+  (package
+    (name "rapicorn")
+    (version "16.0.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "https://testbit.eu/pub/dists/rapicorn/"
+                                  "rapicorn-" version ".tar.xz"))
+              (sha256
+               (base32
+                "1y51yjrpsihas1jy905m9p3r8iiyhq6bwi2690c564i5dnix1f9d"))
+              (patches (search-patches "rapicorn-isnan.patch"))))
+    (build-system gnu-build-system)
+    (arguments
+     `(#:phases
+       (modify-phases %standard-phases
+         (add-after 'unpack 'fix-tests
+           (lambda _
+             ;; Our grep does not support perl regular expressions.
+             (substitute* "taptool.sh"
+               (("grep -P") "grep -E"))
+             ;; Disable path tests because we cannot access /bin or /sbin.
+             (substitute* "rcore/tests/multitest.cc"
+               (("TCMP \\(Path::equals \\(\"/bin\"") "//"))
+             #t))
+         (add-before 'check 'pre-check
+           (lambda _
+             ;; The test suite requires a running X server (with DISPLAY
+             ;; number 99 or higher).
+             (system "Xvfb :99 &")
+             (setenv "DISPLAY" ":99")
+             #t))
+         (add-after 'unpack 'replace-fhs-paths
+           (lambda _
+             (substitute* (cons "Makefile.decl"
+                                (find-files "." "^Makefile\\.in$"))
+               (("/bin/ls") (which "ls"))
+               (("/usr/bin/env") (which "env")))
+             #t)))))
+    ;; These libraries are listed in the "Required" section of the pkg-config
+    ;; file.
+    (propagated-inputs
+     `(("librsvg" ,librsvg)
+       ("cairo" ,cairo)
+       ("pango" ,pango)
+       ("libxml2" ,libxml2)
+       ("python2-enum34" ,python2-enum34)))
+    (inputs
+     `(("gdk-pixbuf" ,gdk-pixbuf)
+       ("libpng" ,libpng-1.2)
+       ("readline" ,readline)
+       ("libcroco" ,libcroco)
+       ("python" ,python-2)
+       ("cython" ,python2-cython)))
+    (native-inputs
+     `(("pandoc" ,ghc-pandoc)
+       ("bison" ,bison)
+       ("flex" ,flex)
+       ("doxygen" ,doxygen)
+       ("graphviz" ,graphviz)
+       ("intltool" ,intltool)
+       ("pkg-config" ,pkg-config)
+       ("xvfb" ,xorg-server)))
+    (home-page "http://rapicorn.org")
+    (synopsis "Toolkit for rapid development of user interfaces")
+    (description
+     "Rapicorn is a toolkit for rapid development of user interfaces in C++
+and Python.  The user interface is designed in a declarative markup language
+and is connected to the programming logic using data bindings and commands.")
+    (license license:mpl2.0)))
+
 (define-public ctl
   (package
     (name "ctl")
@@ -385,7 +475,7 @@ and understanding different BRDFs (and other component functions).")
                                         version ".tar.gz")))
               (sha256
                (base32 "07wii4i824vy9qsvjsgqxppgqmfdxq0xa87i5yk53fijriadq7mb"))
-              (patches (list (search-patch "agg-am_c_prototype.patch")))))
+              (patches (search-patches "agg-am_c_prototype.patch"))))
     (build-system gnu-build-system)
     (arguments
      '(#:configure-flags
