@@ -31,13 +31,17 @@
     (name "tcsh")
     (version "6.18.01")
     (source (origin
-             (method url-fetch)
-             (uri (string-append "ftp://ftp.astron.com/pub/tcsh/tcsh-"
-                                 version ".tar.gz"))
-             (sha256
-              (base32 "1a4z9kwgx1iqqzvv64si34m60gj34p7lp6rrcrb59s7ka5wa476q"))
-             (patches (list (search-patch "tcsh-fix-autotest.patch")))
-             (patch-flags '("-p0"))))
+              (method url-fetch)
+              ;; Old tarballs are moved to old/.
+              (uri (list (string-append "ftp://ftp.astron.com/pub/tcsh/"
+                                        "tcsh-" version ".tar.gz")
+                         (string-append "ftp://ftp.astron.com/pub/tcsh/"
+                                        "old/tcsh-" version ".tar.gz")))
+              (sha256
+               (base32
+                "1a4z9kwgx1iqqzvv64si34m60gj34p7lp6rrcrb59s7ka5wa476q"))
+              (patches (search-patches "tcsh-fix-autotest.patch"))
+              (patch-flags '("-p0"))))
     (build-system gnu-build-system)
     (inputs
      `(("autoconf" ,autoconf)
@@ -58,7 +62,11 @@
             (("; other_script.csh") "; /bin/sh other_script.csh"))
           ;; Now, let's generate the test suite and patch it
           (system* "make" "tests/testsuite")
-          (substitute* "tests/testsuite" (("/bin/sh") (which "sh"))))
+
+          ;; This file is ISO-8859-1 encoded.
+          (with-fluids ((%default-port-encoding #f))
+            (substitute* "tests/testsuite"
+              (("/bin/sh") (which "sh")))))
         (alist-cons-after
          'install 'post-install
          (lambda* (#:key inputs outputs #:allow-other-keys)
