@@ -1,7 +1,9 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
-;;; Copyright © 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2016 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2014 Eric Bavier <bavier@member.fsf.org>
+;;; Copyright © 2015 Jeff Mickey <j@codemac.net>
+;;; Copyright © 2016 Efraim Flashner <efraim@flashner.co.il>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -27,9 +29,10 @@
   #:use-module (gnu packages compression)
   #:use-module (gnu packages gettext)
   #:use-module (gnu packages gnupg)
-  #:use-module (gnu packages openssl)
+  #:use-module (gnu packages linux)
   #:use-module (gnu packages perl)
   #:use-module (gnu packages pkg-config)
+  #:use-module (gnu packages tls)
   #:use-module (gnu packages xml))
 
 (define-public gvpe
@@ -61,26 +64,44 @@ endpoints.")
    (version "0.5.3")
    (source (origin
             (method url-fetch)
-            (uri (string-append "http://www.unix-ag.uni-kl.de/~massar/vpnc/vpnc-"
+            (uri (string-append "https://www.unix-ag.uni-kl.de/~massar/vpnc/vpnc-"
                                 version ".tar.gz"))
             (sha256 (base32
                      "1128860lis89g1s21hqxvap2nq426c9j4bvgghncc1zj0ays7kj6"))
-            (patches (list (search-patch "vpnc-script.patch")))))
+            (patches (search-patches "vpnc-script.patch"))))
    (build-system gnu-build-system)
    (inputs `(("libgcrypt" ,libgcrypt)
-             ("perl" ,perl)))
+             ("perl" ,perl)
+
+             ;; The following packages provide commands that 'vpnc-script'
+             ;; expects.
+             ("net-tools" ,net-tools)             ;ifconfig, route
+             ("iproute2" ,iproute)))              ;ip
    (arguments
     `(#:tests? #f ; there is no check target
       #:phases
-      (alist-replace
-       'configure
-       (lambda* (#:key outputs #:allow-other-keys)
-         (let ((out (assoc-ref outputs "out")))
-           (substitute* "Makefile"
-             (("PREFIX=/usr/local") (string-append "PREFIX=" out)))
-           (substitute* "Makefile"
-             (("ETCDIR=/etc/vpnc") (string-append "ETCDIR=" out "/etc/vpnc")))))
-       %standard-phases)))
+      (modify-phases %standard-phases
+        (replace 'configure
+          (lambda* (#:key outputs #:allow-other-keys)
+            (let ((out (assoc-ref outputs "out")))
+              (substitute* "Makefile"
+                (("PREFIX=/usr/local") (string-append "PREFIX=" out)))
+              (substitute* "Makefile"
+                (("ETCDIR=/etc/vpnc") (string-append "ETCDIR=" out
+                                                     "/etc/vpnc"))))))
+        (add-after 'install 'wrap-vpnc-script
+          (lambda* (#:key inputs outputs #:allow-other-keys)
+            ;; Wrap 'etc/vpnc/vpnc-script' so that it finds the commands it
+            ;; needs.  Assume coreutils/grep/sed are in $PATH.
+            (let ((out (assoc-ref outputs "out")))
+              (wrap-program (string-append out "/etc/vpnc/vpnc-script")
+                `("PATH" ":" prefix
+                  (,(string-append (assoc-ref inputs "net-tools")
+                                   "/sbin")
+                   ,(string-append (assoc-ref inputs "net-tools")
+                                   "/bin")
+                   ,(string-append (assoc-ref inputs "iproute2")
+                                   "/sbin"))))))))))
    (synopsis "Client for Cisco VPN concentrators")
    (description
     "vpnc is a VPN client compatible with Cisco's EasyVPN equipment.
@@ -95,17 +116,17 @@ Only \"Universal TUN/TAP device driver support\" is needed in the kernel.")
 (define-public openconnect
   (package
    (name "openconnect")
-   (version "4.99")
+   (version "7.05")
    (source (origin
             (method url-fetch)
             (uri (string-append "ftp://ftp.infradead.org/pub/openconnect/"
                                 "openconnect-" version ".tar.gz"))
             (sha256 (base32
-                     "1rd8pap455wzkx19i0sy3cqap524b6fwcjvqynxp6lhm01di4bd6"))))
+                     "1i102yr8yp2ny587n6pd966443h1pqxyw5q0n5afq575046jj98g"))))
    (build-system gnu-build-system)
    (inputs
     `(("libxml2" ,libxml2)
-      ("openssl" ,openssl)
+      ("gnutls" ,gnutls)
       ("vpnc" ,vpnc)
       ("zlib" ,zlib)))
    (native-inputs
@@ -124,3 +145,59 @@ supported by the ASA5500 Series, by IOS 12.4(9)T or later on Cisco SR500,
 and probably others.")
    (license license:lgpl2.1)
    (home-page "http://www.infradead.org/openconnect/")))
+
+(define-public openvpn
+  (package
+    (name "openvpn")
+    (version "2.3.9")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append
+                    "https://swupdate.openvpn.org/community/releases/openvpn-"
+                    version ".tar.xz"))
+              (sha256
+               (base32
+                "1hfwmdsp7s34qx34qgwrpp89h30744lbsks6y619cdh27bpnpwaj"))))
+    (build-system gnu-build-system)
+    (arguments
+     '(#:configure-flags '("--enable-iproute2=yes")))
+    (native-inputs
+     `(("iproute2" ,iproute)))
+    (inputs
+     `(("lzo" ,lzo)
+       ("openssl" ,openssl)
+       ("linux-pam" ,linux-pam)))
+    (home-page "https://openvpn.net/")
+    (synopsis "Virtual private network daemon")
+    (description "OpenVPN implements virtual private network (VPN) techniques
+for creating secure point-to-point or site-to-site connections in routed or
+bridged configurations and remote access facilities.  It uses a custom
+security protocol that utilizes SSL/TLS for key exchange.  It is capable of
+traversing network address translators (NATs) and firewalls.")
+    (license license:gpl2)))
+
+(define-public tinc
+  (package
+    (name "tinc")
+    (version "1.0.28")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "http://tinc-vpn.org/packages/"
+                                  name "-" version ".tar.gz"))
+              (sha256
+               (base32
+                "0i5kx3hza359nclyhb60kxlzqyx0phmg175350hww28g6scjcl0b"))))
+    (build-system gnu-build-system)
+    (arguments
+     '(#:configure-flags
+       '("--sysconfdir=/etc"
+         "--localstatedir=/var")))
+    (inputs `(("zlib" ,zlib)
+              ("lzo" ,lzo)
+              ("openssl" ,openssl)))
+    (home-page "http://tinc-vpn.org")
+    (synopsis "Virtual Private Network (VPN) daemon")
+    (description
+     "Tinc is a VPN that uses tunnelling and encryption to create a secure
+private network between hosts on the internet.")
+    (license license:gpl2+)))
