@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2015, 2016 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -18,11 +18,14 @@
 
 (define-module (guix scripts download)
   #:use-module (guix ui)
+  #:use-module (guix scripts)
   #:use-module (guix store)
   #:use-module (guix hash)
   #:use-module (guix utils)
   #:use-module (guix base32)
   #:use-module (guix download)
+  #:use-module ((guix build download) #:select (current-terminal-columns))
+  #:use-module ((guix build syscalls) #:select (terminal-columns))
   #:use-module (web uri)
   #:use-module (ice-9 match)
   #:use-module (srfi srfi-1)
@@ -95,13 +98,17 @@ Supported formats: 'nix-base32' (default), 'base32', and 'base16'
                 (lambda (opt name arg result)
                   (leave (_ "~A: unrecognized option~%") name))
                 (lambda (arg result)
+                  (when (assq 'argument result)
+                    (leave (_ "~A: extraneous argument~%") arg))
+
                   (alist-cons 'argument arg result))
                 %default-options))
 
   (with-error-handling
     (let* ((opts  (parse-options))
            (store (open-connection))
-           (arg   (assq-ref opts 'argument))
+           (arg   (or (assq-ref opts 'argument)
+                      (leave (_ "no download URI was specified~%"))))
            (uri   (or (string->uri arg)
                       (leave (_ "~a: failed to parse URI~%")
                              arg)))
@@ -110,8 +117,10 @@ Supported formats: 'nix-base32' (default), 'base32', and 'base16'
                      (add-to-store store (basename (uri-path uri))
                                    #f "sha256" (uri-path uri)))
                     (else
-                     (download-to-store store (uri->string uri)
-                                        (basename (uri-path uri))))))
+                     (parameterize ((current-terminal-columns
+                                     (terminal-columns)))
+                       (download-to-store store (uri->string uri)
+                                          (basename (uri-path uri)))))))
            (hash  (call-with-input-file
                       (or path
                           (leave (_ "~a: download failed~%")
