@@ -44,6 +44,16 @@ else
     test $? = 42
 fi
 
+# Make sure file-not-found errors in mounts are reported.
+if guix environment --container --ad-hoc --bootstrap guile-bootstrap \
+	--expose=/does-not-exist -- guile -c 1 2> "$tmpdir/error"
+then
+    false
+else
+    grep "/does-not-exist" "$tmpdir/error"
+    grep "[Nn]o such file" "$tmpdir/error"
+fi
+
 # Make sure that the right directories are mapped.
 mount_test_code="
 (use-modules (ice-9 rdelim)
@@ -55,10 +65,15 @@ mount_test_code="
                 (match (string-split line #\space)
                   ;; Empty line.
                   ((\"\") #f)
-                  ;; Ignore these types of file systems.
-                  ((_ _ (or \"tmpfs\" \"proc\" \"sysfs\" \"devtmpfs\"
-                            \"devpts\" \"cgroup\" \"mqueue\") _ _ _)
+                  ;; Ignore the root file system.
+                  ((_ \"/\" _ _ _ _)
                    #f)
+                  ;; Ignore these types of file systems, except if they
+                  ;; correspond to a parent file system.
+                  ((_ mount (or \"tmpfs\" \"proc\" \"sysfs\" \"devtmpfs\"
+                                \"devpts\" \"cgroup\" \"mqueue\") _ _ _)
+                   (and (string-prefix? mount (getcwd))
+		        mount))
                   ((_ mount _ _ _ _)
                    mount)))
               (string-split (call-with-input-file \"/proc/mounts\" read-string)
